
From: Joe Korty <joe.korty@ccur.com>

Fix occasional PCI bus parity errors on the Dell PowerEdge 4600 during
boot.

Symptoms: The LCD display would turn orange and display "PCI SYSTEM E13F5",
and the following message would appear in /var/log/dmesg: "Uhhuh.  NMI
received.  Dazed and confused, but trying to continue".

By inserting a PCI card with a PDC20268 IDE controller and attaching to
that a Sony DRU-510A DVD RW burner with an unloaded tray, the failure can
be made to happen on every boot.

Cause: The aic7xxx driver was resetting the onboard AIC7891 SCSI controller
while waiting for a previous reset to complete.  This second reset confuses
the controller causing it to put bad data onto the PCI bus.

This is a backport of a RedHat 2.4.21-15.ELsmp fix.  A letter discussing
this problem, or one very close to it, may be found at:

   http://lists.us.dell.com/pipermail/linux-poweredge/2003-May/025010.html


Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/scsi/aic7xxx/aic79xx_pci.c |    4 +++-
 drivers/scsi/aic7xxx/aic7xxx_pci.c         |    0 
 2 files changed, 3 insertions(+), 1 deletion(-)

diff -puN drivers/scsi/aic7xxx/aic79xx_pci.c~fix-double-reset-in-aic7xxx-driver drivers/scsi/aic7xxx/aic79xx_pci.c
--- 25/drivers/scsi/aic7xxx/aic79xx_pci.c~fix-double-reset-in-aic7xxx-driver	Mon Jul 12 13:30:20 2004
+++ 25-akpm/drivers/scsi/aic7xxx/aic79xx_pci.c	Mon Jul 12 13:30:20 2004
@@ -452,8 +452,10 @@ ahd_pci_test_register_access(struct ahd_
 	 * or read prefetching could be initiated by the
 	 * CPU or host bridge.  Our device does not support
 	 * either, so look for data corruption and/or flaged
-	 * PCI errors.
+	 * PCI errors.  First pause without causing another
+	 * chip reset.
 	 */
+	hcntrl &= ~CHIPRST;
 	ahd_outb(ahd, HCNTRL, hcntrl|PAUSE);
 	while (ahd_is_paused(ahd) == 0)
 		;
diff -puN drivers/scsi/aic7xxx/aic7xxx_pci.c~fix-double-reset-in-aic7xxx-driver drivers/scsi/aic7xxx/aic7xxx_pci.c
_
